# sks is a daemon application and that's why needs hardening
%global _hardened_build 1

# Define variables to use in conditionals
%if 0%{?fedora} >= 21 || 0%{?rhel} >= 7
%global use_systemd 1
%endif # 0%{?fedora} >= 21 || 0%{?rhel} >= 7

Summary:        Synchronizing Key Server
Name:           sks
Version:        1.1.6
Release:        1%{?dist}
License:        GPLv2+
Group:          System Environment/Daemons
URL:            https://bitbucket.org/skskeyserver/sks-keyserver
Source0:        https://bitbucket.org/skskeyserver/sks-keyserver/downloads/sks-1.1.6.tgz
%if 0%{?use_systemd}
Source1:        sks-db.service
Source2:        sks-recon.service
%else # 0%{?use_systemd}
Source1:        sks-db.init
Source2:        sks-recon.init
%endif # 0%{?use_systemd}
Source3:        cryptokit-1.7-sks-uint32.patch
Patch0:         sks-libdb5.3.patch
Patch1:         sks-build.patch
Patch2:         sks-libdb5.3-2.patch
Patch3:         sks-Makefile.patch
#Patch1:		sks-1.1.1-bdb.patch

BuildRequires:  ocaml ocaml-camlp4-devel libdb-devel zlib-devel chrpath
%if 0%{?fedora} >= 19
BuildRequires: perl-podlators
%endif
%if 0%{?use_systemd}
BuildRequires: systemd-units
%endif

Requires:       libdb
Requires(pre):    /usr/sbin/groupadd /usr/sbin/useradd
%if 0%{?use_systemd}
Requires(post): systemd-units
Requires(post): systemd-sysv
Requires(preun): systemd-units
Requires(postun): systemd-units
%else # 0%{?use_systemd}
Requires(post): chkconfig
Requires(preun): chkconfig
# This is for /sbin/service
Requires(preun): initscripts
Requires(postun): initscripts
%endif # 0%{?use_systemd}

%description
SKS is a OpenPGP keyserver whose goal is to provide easy to
deploy, decentralized, and highly reliable synchronization.

%prep
%setup -q -n sks-1.1.6
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
cp %SOURCE3 .

%build
mv Makefile.local.unused Makefile.local
make dep
make CFLAGS="$RPM_OPT_FLAGS -I`ocamlc -where` -I ." all

%install
make install PREFIX="%{buildroot}%{_prefix}" MANDIR="%{buildroot}%{_mandir}"
chmod -x %{buildroot}%{_mandir}/man8/sks.8.gz
chrpath --delete %{buildroot}%{_bindir}/sks
mkdir -p %{buildroot}%{_sbindir}
for TYPE in db recon; do
  ln -s %{_bindir}/%{name}  %{buildroot}%{_sbindir}/%{name}-${TYPE}
done
%if 0%{?use_systemd}
mkdir -p %buildroot%{_unitdir}
install -m 0644 %{SOURCE1} %buildroot%{_unitdir}/sks-db.service
install -m 0644 %{SOURCE2} %buildroot%{_unitdir}/sks-recon.service
%else # 0%{?use_systemd}
mkdir -p %buildroot%{_initrddir}
install -Dp -m0755 %{SOURCE1} %{buildroot}%{_initrddir}/sks-db
install -Dp -m0755 %{SOURCE2} %{buildroot}%{_initrddir}/sks-recon
%endif # 0%{?use_systemd}

%pre
if ! getent group  %{name} >/dev/null 2>&1; then
  /usr/sbin/groupadd -r %{name}
fi
if ! getent passwd %{name} >/dev/null 2>&1; then
  /usr/sbin/useradd  -r -g %{name}       \
        -d %{_localstatedir}/lib/%{name} \
        -c "SKS Service user"            \
        -s /sbin/nologin %{name}
fi
exit 0                  # Always pass

%post
%if 0%{?use_systemd}
%systemd_post sks-db.service
%systemd_post sks-recon.service
%else # 0%{?use_systemd}
# This adds the proper /etc/rc*.d links for the script
/sbin/chkconfig --add %{name}-db
/sbin/chkconfig --add %{name}-recon
%endif # 0%{?use_systemd}

%preun
%if 0%{?use_systemd}
%systemd_preun sks-db.service
%systemd_preun sks-recon.service
%else # 0%{?use_systemd}
if [ $1 -eq 0 ] ; then # Remove
  /sbin/service %{name}-recon stop >/dev/null 2>&1
  /sbin/service %{name}-db    stop >/dev/null 2>&1
  /sbin/chkconfig --del %{name}-recon
  /sbin/chkconfig --del %{name}-db
fi
%endif # 0%{?use_systemd}

%postun
%if 0%{?use_systemd}
%systemd_postun_with_restart sks-db.service
%systemd_postun_with_restart sks-recon.service
%else # 0%{?use_systemd}
if [ "$1" -ge "1" ] ; then
  /sbin/service %{name}-db    condrestart >/dev/null 2>&1 || :
  /sbin/service %{name}-recon condrestart >/dev/null 2>&1 || :
fi
%endif # 0%{?use_systemd}

%triggerin -- prelink, %{_sysconfdir}/prelink.conf
# Prevent prelink from modifying programs
if ! %{__grep} -q "%{_bindir}/{%{name}" %{_sysconfdir}/prelink.conf 2>/dev/null; then
  echo -e "-b %{_bindir}/{%{name},sks_add_mail,spider}" \
        >>%{_sysconfdir}/prelink.conf
fi

%files
%defattr(-,root,root)
%doc ANNOUNCEMENT BUGS CHANGELOG FILES LICENSE README.md TODO UPGRADING VERSION
%doc sampleConfig sampleWeb
%{_bindir}/sks
%{_bindir}/sks_build.sh
%{_bindir}/sks_add_mail
%{_sbindir}/%{name}-db
%{_sbindir}/%{name}-recon
%{_mandir}/man8/sks.8.gz
%if 0%{?use_systemd}
%{_unitdir}/sks-db.service
%{_unitdir}/sks-recon.service
%else # 0%{?use_systemd}
%{_initrddir}/sks-db
%{_initrddir}/sks-recon
%endif # 0%{?use_systemd}

%changelog
* Tue Sep 27 2016 Nick Bebout <nb@fedoraproject.org> - 1.1.6-1
- Update to 1.1.6

* Sun Jun 12 2016 Nick Bebout <nb@fedoraproject.org> - 1.1.5-99.403hg
- Update to latest hg

* Fri Feb 05 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.1.5-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Fri Jun 19 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.5-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Thu Sep 11 2014 Nick Bebout <nb@fedoraproject.org> - 1.1.5-7
- Fix systemd files

* Thu Sep 11 2014 Nick Bebout <nb@fedoraproject.org> - 1.1.5-6
- Add systemd support

* Thu Aug 21 2014 Kevin Fenzi <kevin@scrye.com> - 1.1.5-5
- Rebuild for rpm bug 1131960

* Mon Aug 18 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.5-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Fri Aug 15 2014 Peter Robinson <pbrobinson@fedoraproject.org> 1.1.5-3
- All supprted (primary/secondary) Fedora architectures have ocaml

* Mon Aug 11 2014 Nick Bebout <nb@fedoraproject.org> - 1.1.5-2
- Fix init scripts

* Mon Aug 11 2014 Nick Bebout <nb@fedoraproject.org> - 1.1.5-1
- Upgrade to 1.1.5

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.4-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed Feb 20 2013 Nick Bebout <nb@fedoraproject.org> - 1.1.4-1
- Upgrade to 1.1.4

* Wed Feb 20 2013 Nick Bebout <nb@fedoraproject.org> - 1.1.3-5
- Fix broken build

* Fri Feb 15 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.3-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Fri Jul 27 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Wed May 23 2012 Peter Robinson <pbrobinson@fedoraproject.org> - 1.1.3-2
- Fix ARM arch definition, update spec

* Sat Apr 21 2012 Nick Bebout <nb@fedoraproject.org> - 1.1.3-1
- Upgrade to 1.1.3

* Tue Jan 24 2012 Nick Bebout <nb@fedoraproject.org> - 1.1.3-0.2.20120124hg
- Try to build against libdb 5.2

* Tue Jan 24 2012 Nick Bebout <nb@fedoraproject.org> - 1.1.3-0.1.20120124hg
- Upgrade to John Clizbe's latest sks from mercurial repo so we can use
- css, etc in the webpage

* Thu Jan 19 2012 Nick Bebout <nb@fedoraproject.org> - 1.1.2-2
- Add init.d scripts

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Tue Dec 13 2011 Nick Bebout <nb@fedoraproject.org> - 1.1.2-1
- Upgrade to 1.1.2

* Wed Oct 26 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.1-7
- Rebuilt for glibc bug#747377

* Fri Apr 29 2011 Dan Horák <dan[at]danny.cz> - 1.1.1-6
- updated the supported arch list

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.1-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Tue May 18 2010 Nick Bebout <nb@fedoraproject.org> - 1.1.1-4
- Make bdb patch better

* Tue Apr 20 2010 Nick Bebout <nb@fedoraproject.org> - 1.1.1-3
- Fix FTBFS

* Wed Oct 14 2009 Nick Bebout <nb@fedoraproject.org> - 1.1.1-2
- Add CFLAGS to make all

* Tue Oct 13 2009 Nick Bebout <nb@fedoraproject.org> - 1.1.1-1
- Initial Fedora package based on 1.1.1 of sks
